@@ -45,7 +45,7 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         if(gpu->temperature == gpu->temperature) //FF_GPU_TEMP_UNSET
         {
             ffStrbufAppendS(&output, " - ");
-            ffTempsAppendNum(gpu->temperature, &output, options->tempConfig);
+            ffTempsAppendNum(gpu->temperature, &output, options->tempConfig, &options->moduleArgs);
         }
 
         if(gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET && gpu->dedicated.total != 0)
@@ -61,7 +61,7 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
             if(gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
             {
                 ffStrbufAppendS(&output, ", ");
-                ffPercentAppendNum(&output, (double) gpu->dedicated.used / (double) gpu->dedicated.total * 100.0, options->percent, false);
+                ffPercentAppendNum(&output, (double) gpu->dedicated.used / (double) gpu->dedicated.total * 100.0, options->percent, false, &options->moduleArgs);
             }
             ffStrbufAppendC(&output, ')');
         }
@@ -74,21 +74,21 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
     else
     {
         FF_STRBUF_AUTO_DESTROY tempStr = ffStrbufCreate();
-        ffTempsAppendNum(gpu->temperature, &tempStr, options->tempConfig);
-        ffPrintFormat(FF_GPU_MODULE_NAME, index, &options->moduleArgs, FF_GPU_NUM_FORMAT_ARGS, (FFformatarg[]){
-            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->vendor},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->name},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->driver},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &tempStr},
-            {FF_FORMAT_ARG_TYPE_INT, &gpu->coreCount},
-            {FF_FORMAT_ARG_TYPE_STRING, type},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->dedicated.total},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->dedicated.used},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->shared.total},
-            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->shared.used},
-            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->platformApi},
-            {FF_FORMAT_ARG_TYPE_DOUBLE, &gpu->frequency},
-        });
+        ffTempsAppendNum(gpu->temperature, &tempStr, options->tempConfig, &options->moduleArgs);
+        FF_PRINT_FORMAT_CHECKED(FF_GPU_MODULE_NAME, index, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_GPU_NUM_FORMAT_ARGS, ((FFformatarg[]) {
+            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->vendor, "vendor"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->name, "name"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->driver, "driver"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &tempStr, "temperature"},
+            {FF_FORMAT_ARG_TYPE_INT, &gpu->coreCount, "core-count"},
+            {FF_FORMAT_ARG_TYPE_STRING, type, "type"},
+            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->dedicated.total, "dedicated-total"},
+            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->dedicated.used, "dedicated-used"},
+            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->shared.total, "shared-total"},
+            {FF_FORMAT_ARG_TYPE_UINT64, &gpu->shared.used, "shared-used"},
+            {FF_FORMAT_ARG_TYPE_STRBUF, &gpu->platformApi, "platform-api"},
+            {FF_FORMAT_ARG_TYPE_DOUBLE, &gpu->frequency, "frequency"},
+        }));
     }
 }
 
@@ -98,7 +98,7 @@ void ffPrintGPU(FFGPUOptions* options)
     const char* error = ffDetectGPU(options, &gpus);
     if (error)
     {
-        ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, "%s", error);
+        ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
         return;
     }
 
@@ -120,13 +120,14 @@ void ffPrintGPU(FFGPUOptions* options)
         printGPUResult(options, selectedGPUs.length == 1 ? 0 : (uint8_t) (i + 1), * (const FFGPUResult**) ffListGet(&selectedGPUs, i));
 
     if(selectedGPUs.length == 0)
-        ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, "No GPUs found");
+        ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "No GPUs found");
 
     FF_LIST_FOR_EACH(FFGPUResult, gpu, gpus)
     {
         ffStrbufDestroy(&gpu->vendor);
         ffStrbufDestroy(&gpu->name);
         ffStrbufDestroy(&gpu->driver);
+        ffStrbufDestroy(&gpu->platformApi);
     }
 }
 
@@ -143,9 +144,16 @@ bool ffParseGPUCommandOptions(FFGPUOptions* options, const char* key, const char
         return true;
     }
 
-    if (ffStrEqualsIgnCase(subKey, "force-vulkan"))
+    if (ffStrEqualsIgnCase(subKey, "detection-method"))
     {
-        options->forceVulkan = ffOptionParseBoolean(value);
+        options->detectionMethod = (FFGPUDetectionMethod) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+            { "auto", FF_GPU_DETECTION_METHOD_AUTO },
+            { "pci", FF_GPU_DETECTION_METHOD_PCI },
+            { "vulkan", FF_GPU_DETECTION_METHOD_VULKAN },
+            { "opencl", FF_GPU_DETECTION_METHOD_OPENCL },
+            { "opengl", FF_GPU_DETECTION_METHOD_OPENGL },
+            {},
+        });
         return true;
     }
 
@@ -190,9 +198,21 @@ void ffParseGPUJsonObject(FFGPUOptions* options, yyjson_val* module)
             continue;
         }
 
-        if (ffStrEqualsIgnCase(key, "forceVulkan"))
+        if (ffStrEqualsIgnCase(key, "detectionMethod"))
         {
-            options->forceVulkan = yyjson_get_bool(val);
+            int value;
+            const char* error = ffJsonConfigParseEnum(val, &value, (FFKeyValuePair[]) {
+                { "auto", FF_GPU_DETECTION_METHOD_AUTO },
+                { "pci", FF_GPU_DETECTION_METHOD_PCI },
+                { "vulkan", FF_GPU_DETECTION_METHOD_VULKAN },
+                { "opencl", FF_GPU_DETECTION_METHOD_OPENCL },
+                { "opengl", FF_GPU_DETECTION_METHOD_OPENGL },
+                {},
+            });
+            if (error)
+                ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Invalid %s value: %s", key, error);
+            else
+                options->detectionMethod = (FFGPUDetectionMethod) value;
             continue;
         }
 
@@ -206,7 +226,7 @@ void ffParseGPUJsonObject(FFGPUOptions* options, yyjson_val* module)
                 {},
             });
             if (error)
-                ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, "Invalid %s value: %s", key, error);
+                ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Invalid %s value: %s", key, error);
             else
                 options->hideType = (FFGPUType) value;
             continue;
@@ -215,7 +235,7 @@ void ffParseGPUJsonObject(FFGPUOptions* options, yyjson_val* module)
         if (ffPercentParseJsonObject(key, val, &options->percent))
             continue;
 
-        ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, "Unknown JSON key %s", key);
+        ffPrintError(FF_GPU_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
     }
 }
 
@@ -229,8 +249,27 @@ void ffGenerateGPUJsonConfig(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
     if (options->driverSpecific != defaultOptions.driverSpecific)
         yyjson_mut_obj_add_bool(doc, module, "driverSpecific", options->driverSpecific);
 
-    if (options->forceVulkan != defaultOptions.forceVulkan)
-        yyjson_mut_obj_add_bool(doc, module, "forceVulkan", options->forceVulkan);
+    if (options->detectionMethod != defaultOptions.detectionMethod)
+    {
+        switch (options->detectionMethod)
+        {
+            case FF_GPU_DETECTION_METHOD_AUTO:
+                yyjson_mut_obj_add_str(doc, module, "detectionMethod", "auto");
+                break;
+            case FF_GPU_DETECTION_METHOD_PCI:
+                yyjson_mut_obj_add_str(doc, module, "detectionMethod", "pci");
+                break;
+            case FF_GPU_DETECTION_METHOD_VULKAN:
+                yyjson_mut_obj_add_str(doc, module, "detectionMethod", "vulkan");
+                break;
+            case FF_GPU_DETECTION_METHOD_OPENCL:
+                yyjson_mut_obj_add_str(doc, module, "detectionMethod", "opencl");
+                break;
+            case FF_GPU_DETECTION_METHOD_OPENGL:
+                yyjson_mut_obj_add_str(doc, module, "detectionMethod", "opengl");
+                break;
+        }
+    }
 
     ffTempsGenerateJsonConfig(doc, module, defaultOptions.temp, defaultOptions.tempConfig, options->temp, options->tempConfig);
 
@@ -316,10 +355,9 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
 
         yyjson_mut_obj_add_strbuf(doc, obj, "platformApi", &gpu->platformApi);
 
-        if (gpu->frequency == FF_GPU_FREQUENCY_UNSET)
-            yyjson_mut_obj_add_null(doc, obj, "frequency");
-        else
-            yyjson_mut_obj_add_real(doc, obj, "frequency", gpu->frequency);
+        yyjson_mut_obj_add_real(doc, obj, "frequency", gpu->frequency); // NaN will be output as "null"
+
+        yyjson_mut_obj_add_uint(doc, obj, "deviceId", gpu->deviceId);
     }
 
     FF_LIST_FOR_EACH(FFGPUResult, gpu, gpus)
@@ -327,25 +365,26 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
         ffStrbufDestroy(&gpu->vendor);
         ffStrbufDestroy(&gpu->name);
         ffStrbufDestroy(&gpu->driver);
+        ffStrbufDestroy(&gpu->platformApi);
     }
 }
 
 void ffPrintGPUHelpFormat(void)
 {
-    ffPrintModuleFormatHelp(FF_GPU_MODULE_NAME, "{1} {2}", FF_GPU_NUM_FORMAT_ARGS, (const char* []) {
-        "GPU vendor",
-        "GPU name",
-        "GPU driver",
-        "GPU temperature",
-        "GPU core count",
-        "GPU type",
-        "GPU total dedicated memory",
-        "GPU used dedicated memory",
-        "GPU total shared memory",
-        "GPU used shared memory",
-        "The platform API that GPU supports",
-        "Current frequency in GHz",
-    });
+    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_GPU_MODULE_NAME, "{1} {2}", FF_GPU_NUM_FORMAT_ARGS, ((const char* []) {
+        "GPU vendor - vendor",
+        "GPU name - name",
+        "GPU driver - driver",
+        "GPU temperature - temperature",
+        "GPU core count - core-count",
+        "GPU type - type",
+        "GPU total dedicated memory - dedicated-total",
+        "GPU used dedicated memory - dedicated-used",
+        "GPU total shared memory - shared-total",
+        "GPU used shared memory - shared-used",
+        "The platform API used when detecting the GPU - platform-api",
+        "Current frequency in GHz - frequency",
+    }));
 }
 
 void ffInitGPUOptions(FFGPUOptions* options)
@@ -364,7 +403,7 @@ void ffInitGPUOptions(FFGPUOptions* options)
     ffOptionInitModuleArg(&options->moduleArgs);
 
     options->driverSpecific = false;
-    options->forceVulkan = false;
+    options->detectionMethod = FF_GPU_DETECTION_METHOD_AUTO;
     options->temp = false;
     options->hideType = FF_GPU_TYPE_UNKNOWN;
     options->tempConfig = (FFColorRangeConfig) { 60, 80 };
